@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-import sys
-if sys.version_info[:2] > (2,4): # No doctest.skip in Python 2.4
-    __doc__ = """
+"""
 A collection of utilities for canonicalizing and inspecting graphs.
 
 Among other things, they solve of the problem of deterministic bnode
@@ -48,83 +46,33 @@ Present in both::
     ...         if l: print(l.decode('ascii'))
 
     >>> dump_nt_sorted(in_both) #doctest: +SKIP
-    <http://example.org> <http://example.org/ns#rel> <http://example.org/same> .
-    <http://example.org> <http://example.org/ns#rel> _:cbcaabaaba17fecbc304a64f8edee4335e .
-    _:cbcaabaaba17fecbc304a64f8edee4335e <http://example.org/ns#label> "Same" .
+    <http://example.org>
+        <http://example.org/ns#rel> <http://example.org/same> .
+    <http://example.org>
+        <http://example.org/ns#rel> _:cbcaabaaba17fecbc304a64f8edee4335e .
+    _:cbcaabaaba17fecbc304a64f8edee4335e
+        <http://example.org/ns#label> "Same" .
 
 Only in first::
 
     >>> dump_nt_sorted(in_first) #doctest: +SKIP
-    <http://example.org> <http://example.org/ns#rel> <http://example.org/a> .
-    <http://example.org> <http://example.org/ns#rel> _:cb124e4c6da0579f810c0ffe4eff485bd9 .
-    _:cb124e4c6da0579f810c0ffe4eff485bd9 <http://example.org/ns#label> "A" .
+    <http://example.org>
+        <http://example.org/ns#rel> <http://example.org/a> .
+    <http://example.org>
+        <http://example.org/ns#rel> _:cb124e4c6da0579f810c0ffe4eff485bd9 .
+    _:cb124e4c6da0579f810c0ffe4eff485bd9
+        <http://example.org/ns#label> "A" .
 
 Only in second::
 
     >>> dump_nt_sorted(in_second) #doctest: +SKIP
-    <http://example.org> <http://example.org/ns#rel> <http://example.org/b> .
-    <http://example.org> <http://example.org/ns#rel> _:cb558f30e21ddfc05ca53108348338ade8 .
-    _:cb558f30e21ddfc05ca53108348338ade8 <http://example.org/ns#label> "B" .
+    <http://example.org>
+        <http://example.org/ns#rel> <http://example.org/b> .
+    <http://example.org>
+        <http://example.org/ns#rel> _:cb558f30e21ddfc05ca53108348338ade8 .
+    _:cb558f30e21ddfc05ca53108348338ade8
+        <http://example.org/ns#label> "B" .
 """
-else:
-    __doc__ = """"""
-
-# ======================================================================
-# FAIL: Doctest: rdflib.compare
-# ----------------------------------------------------------------------
-# Traceback (most recent call last):
-#   File "/usr/lib/python2.7/doctest.py", line 2166, in runTest
-#     raise self.failureException(self.format_failure(new.getvalue()))
-# AssertionError: Failed doctest test for rdflib.compare
-#   File "...rdflib/rdflib/compare.py", line 1, in compare
-# 
-# ----------------------------------------------------------------------
-# File "...rdflib/rdflib/compare.py", line 48, in rdflib.compare
-# Failed example:
-#     dump_nt_sorted(in_both) #doctest +SKIP
-# Expected:
-#     <http://example.org> <http://example.org/ns#rel> <http://example.org/same> .
-#     <http://example.org> <http://example.org/ns#rel> _:cbcaabaaba17fecbc304a64f8edee4335e .
-#     _:cbcaabaaba17fecbc304a64f8edee4335e <http://example.org/ns#label> "Same" .
-# Got:
-#     <http://example.org> <http://example.org/ns#rel> <http://example.org/same> .
-# ----------------------------------------------------------------------
-# File "...rdflib/rdflib/compare.py", line 55, in rdflib.compare
-# Failed example:
-#     dump_nt_sorted(in_first) #doctest +SKIP
-# Expected:
-#     <http://example.org> <http://example.org/ns#rel> <http://example.org/a> .
-#     <http://example.org> <http://example.org/ns#rel> _:cb124e4c6da0579f810c0ffe4eff485bd9 .
-#     _:cb124e4c6da0579f810c0ffe4eff485bd9 <http://example.org/ns#label> "A" .
-# Got:
-#     <http://example.org> <http://example.org/ns#rel> <http://example.org/a> .
-#     <http://example.org> <http://example.org/ns#rel> _:cb189fca567334c3d20481a6d4035592bc .
-#     <http://example.org> <http://example.org/ns#rel> _:cbd80360ccf6ce9f9aa20dd0a4e90027e4 .
-#     _:cb65019af46ad8af18df6cbce90af81a02 <http://example.org/ns#label> "Same" .
-#     _:cba6f22538a1d3cf645d95dcc441170f24 <http://example.org/ns#label> "A" .
-# ----------------------------------------------------------------------
-# File "...rdflib/rdflib/compare.py", line 62, in rdflib.compare
-# Failed example:
-#     dump_nt_sorted(in_second) #doctest +SKIP
-# Expected:
-#     <http://example.org> <http://example.org/ns#rel> <http://example.org/b> .
-#     <http://example.org> <http://example.org/ns#rel> _:cb558f30e21ddfc05ca53108348338ade8 .
-#     _:cb558f30e21ddfc05ca53108348338ade8 <http://example.org/ns#label> "B" .
-# Got:
-#     <http://example.org> <http://example.org/ns#rel> <http://example.org/b> .
-#     <http://example.org> <http://example.org/ns#rel> _:cbd4f503467ab75a1056349c4eb47ac6ea .
-#     <http://example.org> <http://example.org/ns#rel> _:cbd6fd45be5f6f1a929dca5f11f72ccae2 .
-#     _:cb8a1b89fb2a3e9e99143f2dffbc5e0bf4 <http://example.org/ns#label> "B" .
-#     _:cbc9878f3250eee5de9cb6212906a0972f <http://example.org/ns#label> "Same" .
-# 
-# -------------------- >> begin captured logging << --------------------
-# rdflib: INFO: version: 3.3.0-dev
-# --------------------- >> end captured logging << ---------------------
-# 
-# ----------------------------------------------------------------------
-# Ran 2 tests in 0.200s
-# 
-# FAILED (failures=1)
 
 
 # TODO:
@@ -132,21 +80,24 @@ else:
 # - Add warning and/or safety mechanism before working on large graphs?
 # - use this in existing Graph.isomorphic?
 
-__all__ = ['IsomorphicGraph', 'to_isomorphic', 'isomorphic', 'to_canonical_graph', 'graph_diff', 'similar']
- 
+__all__ = ['IsomorphicGraph', 'to_isomorphic', 'isomorphic',
+           'to_canonical_graph', 'graph_diff', 'similar']
+
 from rdflib.graph import Graph, ConjunctiveGraph, ReadOnlyGraphAggregate
 from rdflib.term import BNode
 try:
     import hashlib
-    md = hashlib.md5()
+    md = hashlib.md5
 except ImportError:
     # for Python << 2.5
     import md5
-    md = md5.new()
+    md = md5.new
+
 
 class IsomorphicGraph(ConjunctiveGraph):
     """
-    Ported from <http://www.w3.org/2001/sw/DataAccess/proto-tests/tools/rdfdiff.py>
+    Ported from
+    <http://www.w3.org/2001/sw/DataAccess/proto-tests/tools/rdfdiff.py>
     (Sean B Palmer's RDF Graph Isomorphism Tester).
     """
 
@@ -160,12 +111,12 @@ class IsomorphicGraph(ConjunctiveGraph):
         elif len(self) != len(other):
             return False
         elif list(self) == list(other):
-            return True # TODO: really generally cheaper?
+            return True  # TODO: really generally cheaper?
         return self.internal_hash() == other.internal_hash()
 
     def __ne__(self, other):
-       """Negative graph isomorphism testing."""
-       return not self.__eq__(other)
+        """Negative graph isomorphism testing."""
+        return not self.__eq__(other)
 
     def internal_hash(self):
         """
@@ -184,7 +135,7 @@ class _TripleCanonicalizer(object):
 
     def to_hash(self):
         return self.hashfunc(tuple(sorted(
-                map(self.hashfunc, self.canonical_triples()) )))
+            map(self.hashfunc, self.canonical_triples()))))
 
     def canonical_triples(self):
         for triple in self.graph:
@@ -193,13 +144,13 @@ class _TripleCanonicalizer(object):
     def _canonicalize_bnodes(self, triple):
         for term in triple:
             if isinstance(term, BNode):
-                yield BNode(value="cb%s"%self._canonicalize(term))
+                yield BNode(value="cb%s" % self._canonicalize(term))
             else:
                 yield term
 
     def _canonicalize(self, term, done=False):
         return self.hashfunc(tuple(sorted(self._vhashtriples(term, done),
-                                                    key=_hetero_tuple_key)))
+                                          key=_hetero_tuple_key)))
 
     def _vhashtriples(self, term, done):
         for triple in self.graph:
@@ -214,7 +165,8 @@ class _TripleCanonicalizer(object):
                 yield i
             else:
                 yield self._canonicalize(term, done=True)
-                
+
+
 def _hetero_tuple_key(x):
     "Sort like Python 2 - by name of type, then by value. Expects tuples."
     return tuple((type(a).__name__, a) for a in x)
@@ -257,7 +209,8 @@ def isomorphic(graph1, graph2):
         >>> isomorphic(g1, g3)
         False
     """
-    return _TripleCanonicalizer(graph1).to_hash() == _TripleCanonicalizer(graph2).to_hash()
+    return _TripleCanonicalizer(graph1).to_hash() == \
+        _TripleCanonicalizer(graph2).to_hash()
 
 
 def to_canonical_graph(g1):
@@ -277,14 +230,14 @@ def graph_diff(g1, g2):
     # bnodes have deterministic values in canonical graphs:
     cg1 = to_canonical_graph(g1)
     cg2 = to_canonical_graph(g2)
-    in_both = cg1*cg2
-    in_first = cg1-cg2
-    in_second = cg2-cg1
+    in_both = cg1 * cg2
+    in_first = cg1 - cg2
+    in_second = cg2 - cg1
     return (in_both, in_first, in_second)
 
 
 def _md5_hash(t):
-    h = md
+    h = md()
     for i in t:
         if isinstance(i, tuple):
             h.update(_md5_hash(i).encode('ascii'))
@@ -295,6 +248,7 @@ def _md5_hash(t):
 
 _MOCK_BNODE = BNode()
 
+
 def similar(g1, g2):
     """
     Checks if the two graphs are "similar", by comparing sorted triples where
@@ -306,14 +260,15 @@ def similar(g1, g2):
     """
     return all(t1 == t2 for (t1, t2) in _squashed_graphs_triples(g1, g2))
 
+
 def _squashed_graphs_triples(g1, g2):
     for (t1, t2) in zip(sorted(_squash_graph(g1)), sorted(_squash_graph(g2))):
         yield t1, t2
 
+
 def _squash_graph(graph):
     return (_squash_bnodes(triple) for triple in graph)
 
+
 def _squash_bnodes(triple):
     return tuple((isinstance(t, BNode) and _MOCK_BNODE) or t for t in triple)
-
-
